@@ -200,12 +200,33 @@ class TPM_FRIENDLY_INT(int):
         return self.__class__(int(self).__xor__(value))
 
     @staticmethod
-    def _fix_const_type(cls):
-        for k, v in vars(cls).items():
-            if not isinstance(v, int) or k.startswith("_"):
+    def _copy_and_set(dstcls, srccls):
+        """Copy class variables from srccls to dstcls
+
+        srccls must be a subclass on TPM_FRIENDLY_INT.
+        Sets the the variable type to dstcls when copying.
+        dstcls and srccls can be the same.
+        Skip setting destination if the dstcls variable already have the correct type.
+        """
+        if not issubclass(srccls, TPM_FRIENDLY_INT):
+            return
+        for k, v in vars(srccls).items():
+            dv = getattr(dstcls, k, None)
+            if not isinstance(v, int) or k.startswith("_") or type(dv) == type(dstcls):
                 continue
-            fv = cls(v)
-            setattr(cls, k, fv)
+            fv = dstcls(v)
+            setattr(dstcls, k, fv)
+
+    @staticmethod
+    def _fix_const_type(cls):
+        """Ensure constants in a TPM2 constant class have the correct type
+
+        We also copy constants from a superclass in case it's of the correct type.
+        """
+        for sc in cls.__mro__:
+            if sc in (TPM_FRIENDLY_INT, TPMA_FRIENDLY_INTLIST):
+                break
+            TPM_FRIENDLY_INT._copy_and_set(cls, sc)
         return cls
 
 
@@ -483,7 +504,9 @@ class TPM2_ALG(TPM_FRIENDLY_INT):
     LAST = lib.TPM2_ALG_LAST
 
 
-TPM2_ALG_ID = TPM2_ALG
+@TPM_FRIENDLY_INT._fix_const_type
+class TPM2_ALG_ID(TPM2_ALG):
+    pass
 
 
 @TPM_FRIENDLY_INT._fix_const_type
@@ -508,7 +531,9 @@ class TPM2_ECC(TPM_FRIENDLY_INT):
     }
 
 
-TPM2_ECC_CURVE = TPM2_ECC
+@TPM_FRIENDLY_INT._fix_const_type
+class TPM2_ECC_CURVE(TPM2_ECC):
+    pass
 
 
 @TPM_FRIENDLY_INT._fix_const_type
@@ -947,6 +972,17 @@ class TSS2_RC(TPM_BASE_RC):
         FAPI_RC_NO_HANDLE = lib.TSS2_FAPI_RC_NO_HANDLE
         FAPI_RC_NOT_PROVISIONED = lib.TSS2_FAPI_RC_NOT_PROVISIONED
         FAPI_RC_ALREADY_PROVISIONED = lib.TSS2_FAPI_RC_ALREADY_PROVISIONED
+    if _lib_version_atleast("tss2-policy", "3.2.0-63-gdcdc8412"):
+        POLICY_RC_GENERAL_FAILURE = lib.TSS2_POLICY_RC_GENERAL_FAILURE
+        POLICY_RC_IO_ERROR = lib.TSS2_POLICY_RC_IO_ERROR
+        POLICY_RC_AUTHORIZATION_UNKNOWN = lib.TSS2_POLICY_RC_AUTHORIZATION_UNKNOWN
+        POLICY_RC_BAD_VALUE = lib.TSS2_POLICY_RC_BAD_VALUE
+        POLICY_RC_MEMORY = lib.TSS2_POLICY_RC_MEMORY
+        POLICY_RC_BAD_REFERENCE = lib.TSS2_POLICY_RC_BAD_REFERENCE
+        POLICY_RC_BAD_TEMPLATE = lib.TSS2_POLICY_RC_BAD_TEMPLATE
+        POLICY_RC_POLICY_NOT_CALCULATED = lib.TSS2_POLICY_RC_POLICY_NOT_CALCULATED
+        POLICY_RC_BUFFER_TOO_SMALL = lib.TSS2_POLICY_RC_BUFFER_TOO_SMALL
+        POLICY_RC_NULL_CALLBACK = lib.TSS2_POLICY_RC_NULL_CALLBACK
 
 
 @TPM_FRIENDLY_INT._fix_const_type
@@ -1015,6 +1051,20 @@ class TPM2_CAP(TPM_FRIENDLY_INT):
     VENDOR_PROPERTY = lib.TPM2_CAP_VENDOR_PROPERTY
 
 
+@TPM_FRIENDLY_INT._fix_const_type
+class TPMI_YES_NO(TPM_FRIENDLY_INT):
+    YES = lib.TPM2_YES
+    NO = lib.TPM2_NO
+
+
+@TPM_FRIENDLY_INT._fix_const_type
+class TPM_AT(TPM_FRIENDLY_INT):
+    ANY = lib.TPM_AT_ANY
+    ERROR = lib.TPM_AT_ERROR
+    PV1 = lib.TPM_AT_PV1
+    VEND = lib.TPM_AT_VEND
+
+
 @TPM_FRIENDLY_INT._fix_const_type
 class TPM2_PT(TPM_FRIENDLY_INT):
     NONE = lib.TPM2_PT_NONE
@@ -1305,7 +1355,9 @@ class TPM2_CLOCK(TPM_FRIENDLY_INT):
     COARSE_FASTER = lib.TPM2_CLOCK_COARSE_FASTER
 
 
-TPM2_CLOCK_ADJUST = TPM2_CLOCK
+@TPM_FRIENDLY_INT._fix_const_type
+class TPM2_CLOCK_ADJUST(TPM2_CLOCK):
+    pass
 
 
 @TPM_FRIENDLY_INT._fix_const_type
@@ -1479,3 +1531,9 @@ class TPMA_MODES(TPMA_FRIENDLY_INTLIST):
 class FAPI_ESYSBLOB(TPM_FRIENDLY_INT):
     CONTEXTLOAD = 1
     DESERIALIZE = 2
+
+
+@TPM_FRIENDLY_INT._fix_const_type
+class TSS2_POLICY_PCR_SELECTOR(TPM_FRIENDLY_INT):
+    PCR_SELECT = 0
+    PCR_SELECTION = 1
